==> static_suite-1.0.0-alpha2.tar.gz: static_suite/modules/static_export/src/Commands/EntityCommands.php <==
<?php

namespace Drupal\static_export\Commands;

use Drupal\Component\Plugin\Exception\PluginException;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\static_export\Exporter\Type\Entity\EntityExporterPluginManagerInterface;
use Drupal\static_suite\Entity\EntityUtils;
use Drupal\static_export\File\FileCollectionFormatter;
use Drupal\static_suite\StaticSuiteUserException;
use Drush\Commands\DrushCommands;
use Throwable;

/**
 * A Drush command file to export data.
 */
class EntityCommands extends DrushCommands {

  /**
   * Entity Utils.
   *
   * @var \Drupal\static_suite\Entity\EntityUtils
   */
  protected $entityUtils;

  /**
   * Entity Utils.
   *
   * @var \Drupal\static_export\File\FileCollectionFormatter
   */
  protected $fileCollectionFormatter;

  /**
   * Entity Exporter Manager.
   *
   * @var \Drupal\static_export\Exporter\Type\Entity\EntityExporterPluginManagerInterface
   */
  protected $entityExporterPluginManager;

  /**
   * StaticExportCommands constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The config factory.
   * @param \Drupal\static_export\Exporter\Type\Entity\EntityExporterPluginManagerInterface $entityExporterPluginManager
   *   Entity Exporter Manager.
   * @param \Drupal\static_suite\Entity\EntityUtils $entityUtils
   *   Utils for working with entities.
   * @param \Drupal\static_export\File\FileCollectionFormatter $fileCollectionFormatter
   *   File collection formatter.
   */
  public function __construct(
    ConfigFactoryInterface $configFactory,
    EntityExporterPluginManagerInterface $entityExporterPluginManager,
    EntityUtils $entityUtils,
    FileCollectionFormatter $fileCollectionFormatter
  ) {
    parent::__construct();
    $this->entityExporterPluginManager = $entityExporterPluginManager;
    $this->entityUtils = $entityUtils;
    $this->fileCollectionFormatter = $fileCollectionFormatter;
  }

  /**
   * Exports an entity.
   *
   * @param string $entityTypeId
   *   The entity type id to export, e.g., node, user, etc.
   * @param string $entityId
   *   The ID of the entity to export, based on the previous entityType param.
   * @param array $execOptions
   *   An associative array of options whose values come
   *   from cli, aliases, config, etc.
   *
   * @command static-export:export-entity
   *
   * @option standalone Flag to set standalone mode (default standalone FALSE)
   * @option force-write Whether it should force the writing of the output
   * @usage drush see node 1
   *   Export node 1
   * @usage drush see node 1
   *   Export node 1 in json format to default location
   * @aliases see, static-export-entity
   *
   * @static_export Annotation for drush hooks.
   * @static_export_data_dir_write Annotation for commands that write data.
   */
  public function exportEntity(
    string $entityTypeId,
    string $entityId,
    array $execOptions = [
      'standalone' => FALSE,
      'log-to-file' => TRUE,
      'lock' => TRUE,
      'build' => FALSE,
      'force-write' => FALSE,
    ]
  ) {
    $timeStart = microtime(TRUE);
    try {
      $entityExporter = $this->entityExporterPluginManager->getDefaultInstance();
      $entityExporter->setMustBuild($execOptions['build']);
      $entityExporter->setIsForceWrite($execOptions['force-write']);
      $fileCollectionGroup = $entityExporter->export(
        [
          $entityExporter::PARAM_ENTITY_TYPE_ID => $entityTypeId,
          $entityExporter::PARAM_ENTITY_ID => $entityId,
        ],
        $execOptions['standalone'],
        $execOptions['log-to-file'],
        $execOptions['lock']
      );
      foreach ($fileCollectionGroup->getFileCollections() as $fileCollection) {
        $this->fileCollectionFormatter->setFileCollection($fileCollection);
        $this->output()->writeln($this->fileCollectionFormatter->getTextLines());
      }
      $this->output()->writeln("TOTAL TIME: " . (round(microtime(TRUE) - $timeStart, 3)) . " secs.");
    }
    catch (StaticSuiteUserException | PluginException $e) {
      $this->logger()->error($e->getMessage());
    }
    catch (Throwable $e) {
      $this->logger()->error($e);
    }
  }

  /**
   * Exports an entity type.
   *
   * @param string $entityTypeId
   *   The entity type to export, e.g., node, user, etc.
   * @param int $rangeStart
   *   Range start.
   * @param int $rangeLength
   *   Range length.
   * @param array $execOptions
   *   An associative array of options whose values come
   *   from cli, aliases, config, etc.
   *
   * @command static-export:export-entity-type
   *
   * @option standalone Flag to set standalone mode (default standalone FALSE)
   *   Even thought this command exports all data from a bundle and it should
   *   be executed in standalone mode, we maintain this option's default
   *   value as FALSE to avoid confusing behavior between similar commands.
   *   Hence, yo need to explicitly call this command with "--standalone" option
   *   so it works as expected. Calling it without that option won't broke
   *   anything, but it will take a lot more time to finish and will export
   *   some data more than once.
   * @usage drush static-export:export-entity-type node --bundle=article
   *   Export node article bundle
   *
   * @static_export Annotation for drush hooks.
   * @static_export_data_dir_write Annotation for commands that write data.
   */
  public function exportBundle(
    string $entityTypeId,
    $rangeStart = 0,
    $rangeLength = 9999999,
    array $execOptions = [
      'bundle' => NULL,
      'status' => NULL,
      'standalone' => FALSE,
      'log-to-file' => TRUE,
      'lock' => TRUE,
      'build' => FALSE,
      'force-write' => FALSE,
    ]
  ) {
    set_time_limit(0);
    $timeStart = microtime(TRUE);
    try {
      $options = [
        'bundle' => $execOptions['bundle'],
        'status' => $execOptions['status'],
      ];
      if ($rangeLength !== 9999999) {
        $options['range'] = [
          'start' => $rangeStart,
          'length' => $rangeLength,
        ];
      }
      if ($entityTypeId === 'node') {
        $options['sort'] = [
          'field' => 'nid',
          'direction' => 'DESC',
        ];
        $entityIds = $this->entityUtils->getEntityIds(
          $entityTypeId,
          $options
        );
      }
      else {
        $entityIds = $this->entityUtils->getEntityIds(
          $entityTypeId,
          $options
        );
      }
      $total = count($entityIds);
      if ($total == 0) {
        $message = "No entities found.";
        $this->logger()->error($message);
      }
      else {
        $delta = 1;
        $entityExporter = $this->entityExporterPluginManager->getDefaultInstance();
        $entityExporter->setMustBuild($execOptions['build']);
        $entityExporter->setIsForceWrite($execOptions['force-write']);
        foreach ($entityIds as $entityId) {
          $fileCollectionGroup = $entityExporter->export(
            [
              $entityExporter::PARAM_ENTITY_TYPE_ID => $entityTypeId,
              $entityExporter::PARAM_ENTITY_ID => $entityId,
            ],
            $execOptions['standalone'],
            $execOptions['log-to-file'],
            $execOptions['lock']
          );
          foreach ($fileCollectionGroup->getFileCollections() as $fileCollection) {
            $this->fileCollectionFormatter->setFileCollection($fileCollection);
            $this->output()->writeln($this->fileCollectionFormatter->getTextLines($delta, $total));
          }
          $delta++;
        }
        $this->output()->writeln("TOTAL TIME: " . (round(microtime(TRUE) - $timeStart, 3)) . " secs.");
      }
    }
    catch (StaticSuiteUserException $e) {
      $this->logger()->error($e->getMessage());
    }
    catch (Throwable $e) {
      $this->logger()->error($e);
    }
  }

}

==> static_suite-1.1.0-alpha2.tar.gz: static_suite/modules/static_export/src/Commands/EntityCommands.php <==
<?php

namespace Drupal\static_export\Commands;

use Drupal\Component\Plugin\Exception\PluginException;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\static_export\Exporter\Type\Entity\EntityExporterPluginManagerInterface;
use Drupal\static_suite\Entity\EntityUtils;
use Drupal\static_export\File\FileCollectionFormatter;
use Drupal\static_suite\StaticSuiteUserException;
use Drush\Commands\DrushCommands;
use Throwable;

/**
 * A Drush command file to export data.
 */
class EntityCommands extends DrushCommands {

  /**
   * Entity Utils.
   *
   * @var \Drupal\static_suite\Entity\EntityUtils
   */
  protected $entityUtils;

  /**
   * Entity Utils.
   *
   * @var \Drupal\static_export\File\FileCollectionFormatter
   */
  protected $fileCollectionFormatter;

  /**
   * Entity Exporter Manager.
   *
   * @var \Drupal\static_export\Exporter\Type\Entity\EntityExporterPluginManagerInterface
   */
  protected $entityExporterPluginManager;

  /**
   * StaticExportCommands constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The config factory.
   * @param \Drupal\static_export\Exporter\Type\Entity\EntityExporterPluginManagerInterface $entityExporterPluginManager
   *   Entity Exporter Manager.
   * @param \Drupal\static_suite\Entity\EntityUtils $entityUtils
   *   Utils for working with entities.
   * @param \Drupal\static_export\File\FileCollectionFormatter $fileCollectionFormatter
   *   File collection formatter.
   */
  public function __construct(
    ConfigFactoryInterface $configFactory,
    EntityExporterPluginManagerInterface $entityExporterPluginManager,
    EntityUtils $entityUtils,
    FileCollectionFormatter $fileCollectionFormatter
  ) {
    parent::__construct();
    $this->entityExporterPluginManager = $entityExporterPluginManager;
    $this->entityUtils = $entityUtils;
    $this->fileCollectionFormatter = $fileCollectionFormatter;
  }

  /**
   * Exports an entity.
   *
   * @param string $entityTypeId
   *   The entity type id to export, e.g., node, user, etc.
   * @param string $entityId
   *   The ID of the entity to export, based on the previous entityType param.
   * @param array $execOptions
   *   An associative array of options whose values come
   *   from cli, aliases, config, etc.
   *
   * @command static-export:export-entity
   *
   * @option standalone Flag to set standalone mode (default standalone FALSE)
   * @option force-write Whether it should force the writing of the output
   * @usage drush see node 1
   *   Export node 1
   * @usage drush see node 1
   *   Export node 1 in json format to default location
   * @aliases see, static-export-entity
   *
   * @static_export Annotation for drush hooks.
   * @static_export_data_dir_write Annotation for commands that write data.
   */
  public function exportEntity(
    string $entityTypeId,
    string $entityId,
    array $execOptions = [
      'standalone' => FALSE,
      'log-to-file' => TRUE,
      'lock' => TRUE,
      'force-write' => FALSE,
    ]
  ) {
    $timeStart = microtime(TRUE);
    try {
      $entityExporter = $this->entityExporterPluginManager->getDefaultInstance();
      $entityExporter->setIsForceWrite($execOptions['force-write']);
      $fileCollectionGroup = $entityExporter->export(
        [
          'entity-type-id' => $entityTypeId,
          'entity-id' => $entityId,
        ],
        $execOptions['standalone'],
        $execOptions['log-to-file'],
        $execOptions['lock']
      );
      foreach ($fileCollectionGroup->getFileCollections() as $fileCollection) {
        $this->fileCollectionFormatter->setFileCollection($fileCollection);
        $this->output()->writeln($this->fileCollectionFormatter->getTextLines());
      }
      $this->output()->writeln("TOTAL TIME: " . (round(microtime(TRUE) - $timeStart, 3)) . " secs.");
    }
    catch (StaticSuiteUserException | PluginException $e) {
      $this->logger()->error($e->getMessage());
    }
    catch (Throwable $e) {
      $this->logger()->error($e);
    }
  }

  /**
   * Exports an entity type.
   *
   * @param string $entityTypeId
   *   The entity type to export, e.g., node, user, etc.
   * @param int $rangeStart
   *   Range start.
   * @param int $rangeLength
   *   Range length.
   * @param array $execOptions
   *   An associative array of options whose values come
   *   from cli, aliases, config, etc.
   *
   * @command static-export:export-entity-type
   *
   * @option standalone Flag to set standalone mode (default standalone FALSE)
   *   Even thought this command exports all data from a bundle and it should
   *   be executed in standalone mode, we maintain this option's default
   *   value as FALSE to avoid confusing behavior between similar commands.
   *   Hence, yo need to explicitly call this command with "--standalone" option
   *   so it works as expected. Calling it without that option won't broke
   *   anything, but it will take a lot more time to finish and will export
   *   some data more than once.
   * @usage drush static-export:export-entity-type node --bundle=article
   *   Export node article bundle
   *
   * @static_export Annotation for drush hooks.
   * @static_export_data_dir_write Annotation for commands that write data.
   */
  public function exportBundle(
    string $entityTypeId,
    $rangeStart = 0,
    $rangeLength = 9999999,
    array $execOptions = [
      'bundle' => NULL,
      'status' => NULL,
      'standalone' => FALSE,
      'log-to-file' => TRUE,
      'lock' => TRUE,
      'force-write' => FALSE,
    ]
  ) {
    set_time_limit(0);
    $timeStart = microtime(TRUE);
    try {
      $options = [
        'bundle' => $execOptions['bundle'],
        'status' => $execOptions['status'],
      ];
      if ($rangeLength !== 9999999) {
        $options['range'] = [
          'start' => $rangeStart,
          'length' => $rangeLength,
        ];
      }
      if ($entityTypeId === 'node') {
        $options['sort'] = [
          'field' => 'nid',
          'direction' => 'DESC',
        ];
        $entityIds = $this->entityUtils->getEntityIds(
          $entityTypeId,
          $options
        );
      }
      else {
        $entityIds = $this->entityUtils->getEntityIds(
          $entityTypeId,
          $options
        );
      }
      $total = count($entityIds);
      if ($total == 0) {
        $message = "No entities found.";
        $this->logger()->error($message);
      }
      else {
        $delta = 1;
        $entityExporter = $this->entityExporterPluginManager->getDefaultInstance();
        $entityExporter->setIsForceWrite($execOptions['force-write']);
        foreach ($entityIds as $entityId) {
          $fileCollectionGroup = $entityExporter->export(
            [
              'entity-type-id' => $entityTypeId,
              'entity-id' => $entityId,
            ],
            $execOptions['standalone'],
            $execOptions['log-to-file'],
            $execOptions['lock']
          );
          foreach ($fileCollectionGroup->getFileCollections() as $fileCollection) {
            $this->fileCollectionFormatter->setFileCollection($fileCollection);
            $this->output()->writeln($this->fileCollectionFormatter->getTextLines($delta, $total));
          }
          $delta++;
        }
        $this->output()->writeln("TOTAL TIME: " . (round(microtime(TRUE) - $timeStart, 3)) . " secs.");
      }
    }
    catch (StaticSuiteUserException $e) {
      $this->logger()->error($e->getMessage());
    }
    catch (Throwable $e) {
      $this->logger()->error($e);
    }
  }

}
